﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Media;

using System.IO;        // ファイルの読み書きに必要
using Microsoft.Win32;  // オープンファイル・ダイアログボックスで使用する。

namespace RichTextBox004
{
    /// <summary>
    /// MainWindow.xaml の相互作用ロジック
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }
        private void SaveRTBContent(object sender, RoutedEventArgs e)
        {
            // 「RichTextBoxの内容を保存」ボタンのクリックイベントを処理します。
            SaveXamlPackage();
        }

        private void LoadRTBContent(object sender, RoutedEventArgs e)
        {
            // 「RichTextBoxの内容の読込」ボタンのクリックイベントを処理します。
            LoadXamlPackage();
        }

        private void PrintRTBContent(object sender, RoutedEventArgs e)
        {
            // 「RichTextBoxの内容の印刷」ボタンのクリックイベントを処理します。
            PrintCommand();

        }

        void SaveXamlPackage()
        {
            // ファイル名をダイアログで指定して保存します。

            // ファイル名を指定します。
            // Configure save file dialog box セーブ・ファイル・ダイアログボックスを設定します。
            SaveFileDialog dlg = new SaveFileDialog();

            dlg.FileName = "Document"; // Default file name 既定のファイル名
            dlg.DefaultExt = ".xaml"; // Default file extension 既定のファイル拡張子
            dlg.Filter = "RichText documents (.xaml)|*.xaml";
            // Filter files by extension 拡張機能によってファイルにフィルターをかけます。

            // Show save file dialog box 既定のファイル拡張子
            Nullable<bool> result = dlg.ShowDialog();

            // Process save file dialog box results セーブ・ファイル・ダイアログボックスを表示します。
            if (result == true)
            {
                // ファイルを保存します。
                TextRange range;
                FileStream fStream;
                range = new TextRange(mainRTB.Document.ContentStart, mainRTB.Document.ContentEnd);
                fStream = new FileStream(dlg.FileName, FileMode.Create);
                range.Save(fStream, DataFormats.XamlPackage);
                fStream.Close();
            }

        }

        void LoadXamlPackage()
        {
            // ファイル名を指定して読み込みます。

            // ファイル名を指定します。
            // Configure open file dialog box オープンファイル・ダイアログボックスを設定します。
            OpenFileDialog dlg = new OpenFileDialog();

            dlg.FileName = "Document"; // Default file name 既定のファイル名
            dlg.DefaultExt = ".xaml"; // Default file extension 既定のファイル拡張子
            dlg.Filter = "RichText documents (.xaml)|*.xaml";
            // Filter files by extension 拡張機能によってファイルにフィルターをかけます。

            // Show open file dialog box オープンファイル・ダイアログボックスを表示します。
            bool? result = dlg.ShowDialog();

            // Process open file dialog box results オープンファイル・ダイアログボックスの結果を処理します。
            if (result == true)
            {
                // ファイルを読み込みます。
                TextRange range;
                FileStream fStream;
                if (File.Exists(dlg.FileName))
                {
                    range = new TextRange(mainRTB.Document.ContentStart, mainRTB.Document.ContentEnd);
                    fStream = new FileStream(dlg.FileName, FileMode.OpenOrCreate);
                    range.Load(fStream, DataFormats.XamlPackage);
                    fStream.Close();
                }
            }
        }

        // Print RichTextBox content
        // RichTextBox内容を印刷する
        private void PrintCommand()
        {
            PrintDialog pd = new PrintDialog();
            if ((pd.ShowDialog() == true))
            {
                // use either one of the below  
                // 以下のどちらかを使用してください。
                pd.PrintVisual(mainRTB as Visual, "printing as visual");
                pd.PrintDocument((((IDocumentPaginatorSource)mainRTB.Document).DocumentPaginator), "printing as paginator");
            }
        }
    }
}
